@@ -1,7 +1,5 @@
-"""SNIRF module for conversion to FIF."""
-
 # Author: Robert Luke <mail@robertluke.net>
 #
 # License: BSD (3-clause)
 
-from ._snirf import write_raw_snirf
+from ._snirf import write_raw_snirf, SPEC_FORMAT_VERSION
